Set number of characters to display for row or column labels
Source:R/allGenerics.R, R/allMethods.R
chmSetDisplayLength-method.RdSets the maximum number of characters to display for row or column labels in the NG-CHM viewer.
Usage
chmSetDisplayLength(chm, displayLength, rowOrCol)
# S4 method for class 'ngchmVersion2'
chmSetDisplayLength(chm, displayLength, rowOrCol)Examples
# Create a new NG-CHM object
chm <- chmNew("New Heat Map")
# Set row labels to display up to 20 characters
chm <- chmSetDisplayLength(chm, 20, "row")
# Set column labels to display up to 15 characters
chm <- chmSetDisplayLength(chm, 15, "col")